﻿namespace NetinaShop.AdminPanel.PWA.Pages;

public class PaymentsPageViewModel : BaseViewModel<ObservableCollection<PaymentSDto>>
{
    private readonly NavigationManager _navigationManager;
    private readonly ISnackbar _snackbar;
    private readonly IUserUtility _userUtility;
    private readonly IDialogService _dialogService;
    private readonly IRestWrapper _restWrapper;

    public string Search = string.Empty;
    public int CurrentPage = 0;
    public int PageCount = 1;

    public PaymentsPageViewModel(NavigationManager navigationManager, ISnackbar snackbar, IUserUtility userUtility, IRestWrapper restWrapper, IDialogService dialogService)
    {
        _navigationManager = navigationManager;
        _snackbar = snackbar;
        _userUtility = userUtility;
        _restWrapper = restWrapper;
        _dialogService = dialogService;
    }

    public override async Task InitializeAsync()
    {
        try
        {
            var token = await _userUtility.GetBearerTokenAsync();
            if (token == null)
                throw new Exception("Token is null");
            IsProcessing = true;
            PageDto.Clear();
            var dto = await _restWrapper.PaymentRestApi.ReadAll(CurrentPage, token);
            dto.ForEach(d => PageDto.Add(d));
            if (PageDto.Count == 20)
                PageCount = 2;
        }
        catch (ApiException ex)
        {
            var exe = await ex.GetContentAsAsync<ApiResult>();
            _snackbar.Add(exe != null ? exe.Message : ex.Content, Severity.Error);
        }
        catch (Exception e)
        {
            _snackbar.Add(e.Message, Severity.Error);
        }
        finally
        {

            IsProcessing = false;
        }
        await base.InitializeAsync();
    }

    public async Task ChangePageAsync(int page)
    {
        CurrentPage = page - 1;
        if (CurrentPage > PageCount - 2)
        {

            try
            {
                IsProcessing = true;
                var token = await _userUtility.GetBearerTokenAsync();
                if (token == null)
                    throw new Exception("Token is null");


                var dto = await _restWrapper.PaymentRestApi.ReadAll(CurrentPage, token);
                dto.ForEach(d => PageDto.Add(d));
                if (PageDto.Count == 20)
                    PageCount = CurrentPage + 2;

            }
            catch (ApiException ex)
            {
                var exe = await ex.GetContentAsAsync<ApiResult>();
                _snackbar.Add(exe != null ? exe.Message : ex.Content, Severity.Error);
            }
            catch (Exception e)
            {
                _snackbar.Add(e.Message, Severity.Error);
            }
            finally
            {

                IsProcessing = false;
            }
        }
    }


    public async Task ShowClicked(PaymentSDto order)
    {
        //DialogOptions maxWidth = new DialogOptions() { MaxWidth = MaxWidth.Large, NoHeader = true, FullWidth = true, DisableBackdropClick = true };
        //var parameters = new DialogParameters<OrderActionDialogBox>();
        //parameters.Add(x => x.Order, order);
        //var dialogResult = await _dialogService.ShowAsync<OrderActionDialogBox>($" سفارش {order.FactorCode}", parameters, maxWidth);
        //var result = await dialogResult.Result;
        //if (!result.Canceled && result.Data is bool and true)
        //{
        //    await InitializeAsync();
        //}
    }
}